==> haskell-libbf-0.6.6-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libBF
version:              0.6.6
visibility:           public
id:                   libBF-0.6.6-9QZZhF1xZHqDmHx7pwGpI2
key:                  libBF-0.6.6-9QZZhF1xZHqDmHx7pwGpI2
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  818fd77068b4a2b3185f1bba19b61894
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libbf
hs-libraries:         HSlibBF-0.6.6-9QZZhF1xZHqDmHx7pwGpI2
extra-libraries:      bf
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-L2Cc1YdcpYH9U2sZW5osde

haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libbf-0.6.6-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libBF
version:              0.6.6
visibility:           public
id:                   libBF-0.6.6-4naPH9e2jJ94BecYkcHIbZ
key:                  libBF-0.6.6-4naPH9e2jJ94BecYkcHIbZ
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  e8c073f397dcbb6e933430f10dd50461
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libbf
hs-libraries:         HSlibBF-0.6.6-4naPH9e2jJ94BecYkcHIbZ
extra-libraries:      bf
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-2TMrYujL0SWBJEdw6jCOMM

haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
